//Starpost Reward script - By WellDoneSnake
//Remake of starpost reward system from my misc. pack release in 2.1.

local function HUDIconSetup(player, timer, patch, trans)
	if player.mo and player.mo.valid
		player.icontimer = timer
		player.icongift = patch
		player.icontransp = trans
	end
end

//Reward Setup
local ringset = {1, 5, 10, 15, 20, 25, 30, 50}
local shieldset = {SH_WHIRLWIND, SH_ARMAGEDDON, SH_ELEMENTAL, SH_FORCE|1, SH_BUBBLEWRAP, SH_ATTRACT, SH_FLAMEAURA, SH_THUNDERCOIN}
local shieldiconset = {"TVWWC0", "TVARC0", "TVELC0", "TVFOC0", "TVBBC0", "TVATC0", "TVFLC0", "TVZPC0"}

local function GiveRandomReward(player)
	local set -- 0 = rings, 1 = shields, 2 = sneakers, 3 = invincibility, 4 = lives
	if player.rings >= 50 then set = P_RandomKey(5) else set = P_RandomKey(1) end

	if set == 1 and player.powers[pw_shield] != SH_NONE -- Don't reward the player with another shield, instead give them rings or the invincibility power-up
		if player.rings >= 50
			local chance = P_RandomChance(FRACUNIT/2)
			if chance then set = 3 else set = 0 end
		else
			set = 0
		end
	end

	if set == 0
		P_GivePlayerRings(player, ringset[P_RandomRange(1, 8)])
		S_StartSound(player.mo, sfx_itemup, player)
		HUDIconSetup(player, 3*TICRATE, "TVRIC0", 0)
	elseif set == 1
		local random
		if player.mo.eflags & (MFE_TOUCHWATER|MFE_UNDERWATER)
			random = P_RandomRange(1, 5)
		else
			random = P_RandomRange(1, 8)
		end
		player.powers[pw_shield] = shieldset[random]
		P_SpawnShieldOrb(player)
		S_StartSound(player.mo, sfx_shield, player)
		HUDIconSetup(player, 3*TICRATE, shieldiconset[random],0)
	elseif set == 2
		player.powers[pw_sneakers] = sneakertics + 1 -- Stolen from the source code :]
		P_PlayJingle(player, JT_SHOES)
		HUDIconSetup(player, 3*TICRATE, "TVSSC0", 0)
	elseif set == 3
		player.powers[pw_invulnerability] = invulntics + 1 -- Also stolen from the source code :P
		P_PlayJingle(player, JT_INV)
		HUDIconSetup(player, 3*TICRATE, "TVIVC0", 0)
	elseif set == 4
		P_GivePlayerLives(player, 1)
		P_PlayLivesJingle(player)
		HUDIconSetup(player, 3*TICRATE, "TV1UC0", 0)
	end
end

//Handle HUD timer & transparency in the player's thinker
addHook("ThinkFrame", do
	for player in players.iterate
		if player.icontimer != nil and player.icontimer > 0
			player.icontimer = $ - 1
			if player.icontimer < TICRATE 
				player.icontransp = $ + 1
				if player.icontransp > 9
					player.icontimer = 0
				end
			end
		end
	end
end)

//Starpost Interaction
local function ItemReward(post, mo)
	local player = mo.player
	if player.bot return end
	//Activate starpost once
	if player.starpostnum < post.health -- Learnt this from FuriousFox's "BonusStage" addon on MB (2.1 archives)
		if player.rings < 1
			P_GivePlayerRings(player, 15)
			S_StartSound(player.mo, sfx_itemup, player)
			HUDIconSetup(player, 3*TICRATE, "TVRIC0", 0)
		else
			GiveRandomReward(player)
		end
	end
end
addHook("TouchSpecial", ItemReward, MT_STARPOST)

//HUD Drawing Power-Up Icons
local function hud_icon(v, stplyr)
	if stplyr.icontimer != nil and stplyr.icontimer > 0
		local icontransp = stplyr.icontransp<<V_ALPHASHIFT
		local iconpatch = (v.cachePatch(stplyr.icongift))
		v.draw(160, 170, iconpatch, icontransp|V_SNAPTOBOTTOM)
	end
end
hud.add(hud_icon)